#include "config.h"
#include "const.h"

/**
 * 构造方法。
 * @param szFileName    配置文件的路径
 */
Config::Config(const char* szFileName) : m_settings(szFileName, QSettings::IniFormat)
{
}

/**
 * 获取服务器 IP 地址。
 * @return 服务器 IP 地址
 */
QHostAddress Config::getServerAddr()
{
    return QHostAddress( m_settings.value(Const::CONFIG_SERVER_ADDR).toString() );
}

/**
 * 设置服务器 IP 地址。
 * @param qsServerAddr  服务器 IP 地址
 */
void Config::setServerAddr(QString qsServerAddr)
{
    m_settings.setValue(Const::CONFIG_SERVER_ADDR, qsServerAddr);
}

/**
 * 获取服务器端口号。
 * @return 服务器端口号
 */
quint16 Config::getServerPort()
{
    return (quint16)( m_settings.value(Const::CONFIG_SERVER_PORT).toUInt() );
}

/**
 * 设置服务器端口号。
 * @param nServerPort   服务器端口号
 */
void Config::setServerPort(quint16 nServerPort)
{
    m_settings.setValue(Const::CONFIG_SERVER_PORT, nServerPort);
}

/**
 * 获取服务器数据库文件路径。
 * @return 服务器数据库文件路径
 */
QString Config::getServerDBPath()
{
    return m_settings.value(Const::CONFIG_SERVER_DB_PATH).toString();
}
