#pragma once

#include <QStringList>
#include "const.h"
#include "result.h"

class Protocol
{
public:
    enum Type
    {
        Logon,              // 登录
        Reg,                // 注册
        Chat,               // 聊天
        MultiChat,          // 群聊
        AddFriendRequest,   // 添加好友请求
        AddFriendResult,    // 添加好友结果
        Logoff,             // 离线请求
        FriendLogon         // 好友登录通知
    };

    Protocol(Type type);
    Type getType();

protected:
    Type m_type;    // 协议类型
};

class LogonRequest : public Protocol
{
public:
    LogonRequest(const QString&, const QString&);
    const char* getUserName() const;
    const char* getPassword() const;

private:
    char m_szUserName[Const::MAX_USER_NAME_LEN + 1];    // 用户名
    char m_szPassword[Const::MAX_PASSWORD_LEN + 1];     // 密码
};

class LogonResult : public Protocol
{
public:
    LogonResult();
    Result::Code getResultCode() const;
    int getIconIndex() const;
    int getFriendsCount() const;
    void getFriendNames(QStringList&) const;
    void getFriendIconIndexs(QList<int>&) const;
    bool isFriendOnline(int) const;
    void setErrorCode(Result::Code);
    void setIconIndex(int);
    void setFriendsCount(int);
    void setFriendNames(const QString&);
    void setFriendIconIndexs(const int*, int);
    void setFriendsOnline(int, bool);

private:
    Result::Code    m_resultCode;                                   // 登录结果
    int             m_nIconIndex;                                   // 头像索引
    int             m_nFriendsCount;                                // 好友数
    char            m_szFriendNames[Const::MAX_FRIEND_NAMES_LEN];   // 好友名列表
    int             m_nFriendIconIndexs[Const::MAX_FRIENDS_COUNT];  // 好友头像索引列表
    bool            m_bFriendsOnline[Const::MAX_FRIENDS_COUNT];     // 好友在线状态列表
};

class RegRequest : public Protocol
{
public:
    RegRequest(const QString&, const QString&, int);
    const char* getUserName() const;
    const char* getPassword() const;
    int getIconIndex() const;

private:
    char    m_szUserName[Const::MAX_USER_NAME_LEN + 1]; // 用户名
    char    m_szPassword[Const::MAX_PASSWORD_LEN + 1];  // 密码
    int     m_nIconIndex;                               // 头像索引
};

class RegResult : public Protocol
{
public:
    RegResult();
    Result::Code getResultCode() const;
    void setErrorCode(Result::Code);

private:
    Result::Code m_resultCode;  // 结果
};

class AddFriendRequest : public Protocol
{
public:
    AddFriendRequest(const QString&, const QString&, int);
    const char* getSrcUserName() const;
    const char* getDstUserName() const;
    int getIconIndex() const;

private:
    char    m_szSrcUserName[Const::MAX_USER_NAME_LEN + 1];  // 源用户名
    char    m_szDstUserName[Const::MAX_USER_NAME_LEN + 1];  // 目标用户名
    int     m_nIconIndex;                                   // 源用户的头像索引
};

class AddFriendResult : public Protocol
{
public:
    AddFriendResult(Result::Code, const QString&, const QString&, int);
    Result::Code getResultCode() const;
    const char* getSrcUserName() const;
    const char* getDstUserName() const;
    int getIconIndex() const;

private:
    Result::Code    m_resultCode;                                   // 结果
    char            m_szSrcUserName[Const::MAX_USER_NAME_LEN + 1];  // 源用户名
    char            m_szDstUserName[Const::MAX_USER_NAME_LEN + 1];  // 目标用户名
    int             m_nDstUserIconIndex;                            // 目标用户的头像索引
};

class Chat_C2S : public Protocol
{
public:
    Chat_C2S(const QString&, const QString&, const QString&);
    const char* getSrcUserName() const;
    const char* getDstUserName() const;
    const char* getContent() const;

private:
    char m_szSrcUserName[Const::MAX_USER_NAME_LEN + 1];     // 源用户名
    char m_szDstUserName[Const::MAX_USER_NAME_LEN + 1];     // 目标用户名
    char m_szContent[Const::MAX_CONTENT_LEN + 1];           // 内容
};

class Chat_S2C: public Chat_C2S
{
public:
    Chat_S2C(const QString&, const QString&, const QString&, const QString&);
    const char* getTime() const;

private:
    char m_szTime[Const::TIME_LEN + 1];     // 发送时间
};

class LogoffRequest : public Protocol
{
public:
    LogoffRequest(const QString&);
    const char* getUserName() const;

private:
    char m_szUserName[Const::MAX_USER_NAME_LEN + 1];    // 用户名
};

class FriendLogon : public Protocol
{
public:
    FriendLogon(const char*);
    const char* getUserName() const;

private:
    char m_szUserName[Const::MAX_USER_NAME_LEN + 1];    // 用户名
};
