#include <QDateTime>
#include <QMessageBox>
#include "chatwindow.h"
#include "ui_chatwindow.h"
#include "client.h"

/**
 * 构造方法。
 * @param qsFriendName  好友名
 * @param parent        父窗口
 */
ChatWindow::ChatWindow(const QString& qsFriendName, QWidget* parent) :
    QDialog(parent),
    ui(new Ui::ChatWindow),
    m_qsFriendName(qsFriendName)
{
    ui->setupUi(this);
    this->setWindowTitle(qsFriendName);
}

/**
 * 析构方法。
 */
ChatWindow::~ChatWindow()
{
    delete ui;
}

/**
 * 设置聊天内容。
 * @param chatInfo  聊天信息
 */
void ChatWindow::setContent(const Chat_S2C* chatInfo)
{
    // 获取好友名、发送时间、聊天内容
    const QString qsFriendName( chatInfo->getSrcUserName() );  // 好友名
    const QString qsTime( chatInfo->getTime() );               // 发送时间
    const QString qsContent( chatInfo->getContent() );         // 内容

    // 显示聊天相关信息
    QString qsShow( qsFriendName + "  [" + qsTime + "]\n" + qsContent + "\n\n" );
    m_qsContent += qsShow;
    ui->teHistory->setText(m_qsContent);
}

/**
 * “发送”按钮的单击响应方法。
 */
void ChatWindow::on_buttonSend_clicked()
{
    // 获取并查检用户输入的聊天内容
    const QString qsContent( ui->teInput->toPlainText() );
    if ( qsContent.length() > Const::MAX_CONTENT_LEN )
    {
        QString qsText( Result::getMessage(Result::CONTENT_IS_TOO_LONG) );
        QMessageBox::critical(this, NULL, qsText);
        return;
    }

    // 获取当前时间
    const QString qsTime( QDateTime::currentDateTime().toString(Const::DATE_TIME_FORMAT) );

    // 显示聊天内容
    QString qsShow( Client::getName() + "  [" + qsTime + "]\n" + qsContent + "\n\n" );
    m_qsContent += qsShow;
    ui->teHistory->setText(m_qsContent);

    // 清空输入框
    ui->teInput->clear();

    // 发送聊天内容
    emit UM_CHAT_C2S(m_qsFriendName, qsContent);
}
