#pragma once

#include <QTcpSocket>
#include "../Common/protocol.h"
#include "../Common/result.h"

class Client : public QTcpSocket
{
    Q_OBJECT

public:
    explicit Client(QWidget* mainWindow = NULL);
    ~Client();
    Result::Code logon();
    Result::Code reg();
    Result::Code chat(const QString&, const QString&);
    Result::Code addFriend(const QString&);
    Result::Code logoff();
    static const QString& getName();

signals:
    void UM_LOGON_SUCCESS(const LogonResult*);          // 登录成功信号
    void UM_REG_SUCCESS();                              // 注册成功信号
    void UM_ADD_FRIEND_SUCCESS(const QString&, int);    // 添加好友成功信号
    void UM_CHAT_S2C(const Chat_S2C*);                  // 接收到来自服务器的聊天信息的信号
    void UM_FRIEND_LOGOFF(const LogoffRequest*);        // 好友离线信号
    void UM_FRIEND_LOGON(const FriendLogon*);           // 好友登录信号

private slots:
    void onGetMessageFromServer();

private:
    void handleLogonResult(const LogonResult*);
    void handleRegResult(const RegResult*);
    void handleChat(const Chat_S2C*);
    void handleAddFriendRequest(const AddFriendRequest*);
    void handleAddFriendResult(const AddFriendResult*);
    void handleLogoffRequest(const LogoffRequest*);
    void handleFriendLogon(const FriendLogon*);

private:
    QWidget*        m_mainWindow;       // 主窗口
    static QString  s_qsName;           // 用户名
    int             m_nIconIndex;       // 头像头像索引
    int             m_nFriendsCount;    // 好友数
};
