#include <QMessageBox>
#include "logonwindow.h"
#include "ui_logonwindow.h"
#include "../Common/const.h"
#include "../Common/result.h"

/**
 * 构造方法。
 * @param parent    父窗口
 */
LogonWindow::LogonWindow(QWidget* parent) :
    QDialog(parent),
    ui(new Ui::LogonWindow)
{
    ui->setupUi(this);
}

/**
 * 析构方法。
 */
LogonWindow::~LogonWindow()
{
    delete ui;
}

/**
 * 获取用户名。
 * @return 用户名
 */
const QString& LogonWindow::getUserName()
{
    return m_qsUserName;
}

/**
 * 获取密码。
 * @return 密码
 */
const QString& LogonWindow::getPassword()
{
    return m_qsPassword;
}

/**
 * “确定”按钮的单击响应方法。
 */
void LogonWindow::on_buttonOK_clicked()
{
    // 检查用户名
    const QString qsUserName( ui->editUserName->text() );
    if ( qsUserName.isEmpty() )                                // 用户名为空
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::USER_NAME_EMPTY) );
        ui->editUserName->setFocus();
        return;
    }
    if ( qsUserName.length() > Const::MAX_USER_NAME_LEN )      // 用户名太长
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::USER_NAME_TOO_LONG) );
        ui->editUserName->setFocus();
        return;
    }
    if ( qsUserName.contains(Const::SPLIT_FLAT) )              // 用户名包含非法字符
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::USER_NAME_INVALID) );
        ui->editUserName->setFocus();
        return;
    }

    // 检查密码
    const QString qsPassword( ui->editPassword->text() );
    if ( qsPassword.isEmpty() )                                // 密码为空
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::PASSWORD_EMPTY) );
        ui->editPassword->setFocus();
        return;
    }
    if ( qsPassword.length() > Const::MAX_USER_NAME_LEN )      // 密码太长
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::PASSWORD_TOO_LONG) );
        ui->editPassword->setFocus();
        return;
    }

    // 保存以上内容到成员变量中
    m_qsUserName = qsUserName;
    m_qsPassword = qsPassword;

    QDialog::accept();
}

/**
 * “取消”按钮的单击响应方法。
 */
void LogonWindow::on_buttonCancel_clicked()
{
    QDialog::reject();
}
