#include <QMessageBox>
#include "regwindow.h"
#include "ui_regwindow.h"
#include "../Common/config.h"
#include "../Common/const.h"
#include "../Common/result.h"

/**
 * 构造方法。
 * @param parent    父窗口
 */
RegWindow::RegWindow(QWidget* parent) :
    QDialog(parent),
    ui(new Ui::RegWindow)
{
    ui->setupUi(this);
    this->addIcons();
}

/**
 *  析构方法。
 */
RegWindow::~RegWindow()
{
    // 删除图标列表中的所有列表项
    const int nCount = ui->listUserIcon->count();
    for (int i = nCount - 1; i >= 0; i--)
    {
        delete ui->listUserIcon->item(i);
    }

    delete ui;
}

/**
 * 获取用户名。
 * @return 用户名
 */
const QString& RegWindow::getUserName()
{
    return m_qsUserName;
}

/**
 * 获取密码。
 * @return 密码
 */
const QString& RegWindow::getPassword()
{
    return m_qsPassword;
}

/**
 * 获取头像索引。
 * @return 头像索引
 */
int RegWindow::getIconIndex()
{
    return m_nIconIndex;
}

/**
 * 添加所有图标到图标列表中。
 */
void RegWindow::addIcons()
{
    for (int i = 1; i <= Const::ICON_COUNT; i++)
    {
        QString qsIconFilePath = QString(Const::ICON_FILE_NAME).arg( i, 2, 10, QLatin1Char('0') );
        QIcon icon(qsIconFilePath);
        QString qsIconFileName = QString("%1.ico").arg( i, 2, 10, QLatin1Char('0') );
        QListWidgetItem* item = new QListWidgetItem(icon, qsIconFileName);
        ui->listUserIcon->addItem(item);
    }
}

/**
 * “确定”按钮的单击响应方法。
 */
void RegWindow::on_buttonOK_clicked()
{
    // 检查用户名
    const QString qsUserName( ui->editUserName->text() );
    if ( qsUserName.isEmpty() )                                // 用户名为空
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::USER_NAME_EMPTY) );
        ui->editUserName->setFocus();
        return;
    }
    if ( qsUserName.length() > Const::MAX_USER_NAME_LEN )      // 用户名太长
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::USER_NAME_TOO_LONG) );
        ui->editUserName->setFocus();
        return;
    }
    if ( qsUserName.contains(Const::SPLIT_FLAT) )              // 用户名包含非法字符
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::USER_NAME_INVALID) );
        ui->editUserName->setFocus();
        return;
    }

    // 检查密码
    const QString qsPassword( ui->editPassword->text() );
    if ( qsPassword.isEmpty() )                                // 密码为空
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::PASSWORD_EMPTY) );
        ui->editPassword->setFocus();
        return;
    }
    if ( qsPassword.length() > Const::MAX_USER_NAME_LEN )      // 密码太长
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::PASSWORD_TOO_LONG) );
        ui->editPassword->setFocus();
        return;
    }
    QString qsRePassword( ui->editRePassword->text() );
    if (qsPassword != qsRePassword)                           // 两次密码不一致
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::PASSWORD_NOT_EQUAL) );
        ui->editRePassword->setFocus();
        return;
    }

    // 检查图标文件名
    QListWidgetItem* item = ui->listUserIcon->currentItem();
    if (item == NULL)
    {
        QMessageBox::critical( this, NULL, Result::getMessage(Result::ICON_NOT_SELECT) );
        ui->listUserIcon->setFocus();
        return;
    }

    // 保存以上内容到成员变量中
    m_qsUserName = qsUserName;
    m_qsPassword = qsPassword;
    m_nIconIndex = item->text().left(2).toInt();

    QDialog::accept();
}

/**
 * “取消”按钮的单击响应方法。
 */
void RegWindow::on_buttonCancel_clicked()
{
    QDialog::reject();
}
