#include <QListWidgetItem>
#include "userlistwidget.h"

/**
 * 构造方法。
 * @param pPrent    父窗口
 */
UserListWidget::UserListWidget(QWidget* prent) : QListWidget(prent)
{
}

/**
 * 添加一个列表项。
 * @param qsItemText        列表项显示的文字
 * @param qsIconFilePath    列表项显示的图标的文件路径
 * @param bColorful         为 true 表示彩色，为 false 表示灰色
 */
void UserListWidget::addItem(const QString& qsItemText,
    const QString& qsIconFilePath, bool bColorful)
{
   QListWidgetItem* item = NULL;

   // 创建彩色图标
   QIcon normalIcon(qsIconFilePath);

   // 创建灰色图标
   QSize size = normalIcon.actualSize(size, QIcon::Disabled, QIcon::Off);
   QPixmap pixmap = normalIcon.pixmap(size, QIcon::Disabled, QIcon::Off);
   QIcon grayIcon(pixmap);

   // 创建列表项
   if (bColorful)
   {
       item = new QListWidgetItem(normalIcon, qsItemText);
   }
   else
   {
       item = new QListWidgetItem(grayIcon, qsItemText);
   }

   // 将列表项加入到列表控件中
   QListWidget::addItem(item);

   // 保存图标
   m_normalIcons.append(normalIcon);
   m_grayIcons.append(grayIcon);
}

/**
 * 改变列表项的颜色(在彩色、灰色之间转换)。
 * @param qsItemText    列表项显示的文字
 * @param bColorful     为 true 表示彩色，为 false 表示灰色
 */
void UserListWidget::changeItemColor(const QString& qsItemText, bool bColorful)
{
    // 查找列表项
    QList<QListWidgetItem*> itemList = this->findItems(qsItemText, Qt::MatchFixedString);
    if ( itemList.isEmpty() )
    {
        return;
    }

    // 取得列表项的索引
    QListWidgetItem* item = itemList.at(0);
    int nIndex = this->row(item);

    // 删除列表项
    delete item;

    // 重新创建列表项
    if (bColorful)
    {
        item = new QListWidgetItem(m_normalIcons[nIndex], qsItemText);
    }
    else
    {
        item = new QListWidgetItem(m_grayIcons[nIndex], qsItemText);
    }

   // 将列表项加入到列表控件中
    this->insertItem(nIndex, item);
}

/**
 * 删除所有保存的图标和列表项。
 */
void UserListWidget::clear()
{
    const int nItemCount = this->count();
    for (int i = nItemCount - 1; i >= 0; i--)
    {
        delete this->item(i);
    }
    m_normalIcons.clear();
    m_grayIcons.clear();
    QListWidget::clear();
}
